<div align="center">
    <img src="https://github.com/viur-framework/viur-artwork/raw/main/icons/icon-assistant.svg" height="196" alt="A hexagonal logo of Assistant" title="Assistant logo"/>
    <h1>viur-assistant</h1>
    <a href="https://pypi.org/project/viur-assistant/">
        <img alt="Badge showing current PyPI version" title="PyPI" src="https://img.shields.io/pypi/v/viur-assistant">
    </a>
    <a href="LICENSE">
        <img src="https://img.shields.io/github/license/viur-framework/viur-assistant" alt="Badge displaying the license" title="License badge">
    </a>
    <br>
    On the way to becoming a AI-based <a href="https://www.viur.dev">ViUR</a> assistant plugin.
</div>
